Certificate class

Constructors

Certificate(String purpose, SplayTreeMap payload, String domain, int timestamp, String signer, {String? signature})
Certificate.fromJsonString(String input)
Certificate.fromMap(Map map)

Properties

domain ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payload ↔ SplayTreeMap
getter/setter pair
purpose ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ String?
getter/setter pair
signer ↔ String
getter/setter pair
timestamp ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() → String
Encode a certificate into json string.
toMap() → SplayTreeMap
toString() → String
A string representation of this object.
inherited
verify() → dynamic
Verify a cert (mainly on signature matching.) throws epection if the certificate is invalid.

Operators

operator ==(Object other) → bool
The equality operator.
inherited