Address class

Constructors

Address()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isAddress(String input) → bool
Check if input is an address
isUncompressedPublicKey(Uint8List input) → bool
Check if the public key is 65 bytes, and starts with 4.
publicKeyToAddressBytes(Uint8List input) → Uint8List
Convert an uncompressed public key to address bytes. (20 bytes)
publicKeyToAddressString(Uint8List input) → String
Convert a public key to address, in string format.
toChecksumAddress(String input) → String
encode the address to checksumed address that is compatible with eip-55