ThorEvent class

Constructors

ThorEvent(String jsonString)

Properties

event ↔ ContractEvent
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeResults(List<String> topics, String data) → List
Returns topics and data
getSignature() → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited