ThorFunction class

Constructors

ThorFunction(String jsonString)

Properties

function ↔ ContractFunction
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeReturnV1(String data) → List<V1ParamWrapper>
encode(List args) → Uint8List
Encode the parameters to Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selector() → Uint8List
Get selector as Uint8List
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited